# HG changeset patch
# Node ID 54de16d4878f8b9c3ac13045409865f394897181
# Parent  567e86fd4234098660d47defa29a5dfca9d55f52
diff --git a/libpurple/purplewhiteboardmanager.h b/libpurple/purplewhiteboardmanager.h
--- a/libpurple/purplewhiteboardmanager.h
+++ b/libpurple/purplewhiteboardmanager.h
@@ -86,36 +86,36 @@
 GListModel *purple_whiteboard_manager_get_default_as_model(void);
 
 /**
- * purple_whiteboard_manager_register:
+ * purple_whiteboard_manager_add:
  * @manager: The #PurpleWhiteboardManager instance.
  * @whiteboard: The #PurpleWhiteboard to register.
  * @error: Return address for a #GError, or %NULL.
  *
- * Registers @whiteboard with @manager.
+ * Adds @whiteboard to @manager.
  *
- * Returns: %TRUE if @whiteboard was successfully registered with @manager,
- *          %FALSE otherwise.
+ * Returns: %TRUE if @whiteboard was successfully added to @manager, %FALSE
+ *          otherwise.
  *
  * Since: 3.0
  */
 PURPLE_AVAILABLE_IN_3_0
-gboolean purple_whiteboard_manager_register(PurpleWhiteboardManager *manager, PurpleWhiteboard *whiteboard, GError **error);
+gboolean purple_whiteboard_manager_add(PurpleWhiteboardManager *manager, PurpleWhiteboard *whiteboard, GError **error);
 
 /**
- * purple_whiteboard_manager_unregister:
+ * purple_whiteboard_manager_remove:
  * @manager: The #PurpleWhiteboardManager instance.
  * @whiteboard: The #PurpleWhiteboard to unregister.
  * @error: Return address for a #GError, or %NULL.
  *
- * Unregisters @whiteboard from @manager.
+ * Removes @whiteboard from @manager.
  *
- * Returns: %TRUE if @whiteboard was successfully unregistered from @manager,
- *          %FALSE otherwise.
+ * Returns: %TRUE if @whiteboard was successfully removed from @manager, %FALSE
+ *          otherwise.
  *
  * Since: 3.0
  */
 PURPLE_AVAILABLE_IN_3_0
-gboolean purple_whiteboard_manager_unregister(PurpleWhiteboardManager *manager, PurpleWhiteboard *whiteboard, GError **error);
+gboolean purple_whiteboard_manager_remove(PurpleWhiteboardManager *manager, PurpleWhiteboard *whiteboard, GError **error);
 
 /**
  * purple_whiteboard_manager_find:

diff --git a/libpurple/purplewhiteboardmanager.c b/libpurple/purplewhiteboardmanager.c
--- a/libpurple/purplewhiteboardmanager.c
+++ b/libpurple/purplewhiteboardmanager.c
@@ -34,8 +34,8 @@
 static GParamSpec *properties[N_PROPERTIES] = {NULL, };
 
 enum {
-	SIG_REGISTERED,
-	SIG_UNREGISTERED,
+	SIG_ADDED,
+	SIG_REMOVED,
 	N_SIGNALS,
 };
 static guint signals[N_SIGNALS] = {0, };
@@ -166,16 +166,16 @@
 	g_object_class_install_properties(obj_class, N_PROPERTIES, properties);
 
 	/**
-	 * PurpleWhiteboardManager::registered:
+	 * PurpleWhiteboardManager::added:
 	 * @manager: The #PurpleWhiteboardManager instance.
 	 * @whiteboard: The #PurpleWhiteboard that was registered.
 	 *
 	 * Emitted after @whiteboard has been registered in @manager.
 	 *
 	 * Since: 3.0
 	 */
-	signals[SIG_REGISTERED] = g_signal_new_class_handler(
-		"registered",
+	signals[SIG_ADDED] = g_signal_new_class_handler(
+		"added",
 		G_OBJECT_CLASS_TYPE(klass),
 		G_SIGNAL_RUN_LAST,
 		NULL,
@@ -187,16 +187,16 @@
 		PURPLE_TYPE_WHITEBOARD);
 
 	/**
-	 * PurpleWhiteboardManager::unregistered:
+	 * PurpleWhiteboardManager::removed:
 	 * @manager: The #PurpleWhiteboardManager instance.
 	 * @whiteboard: The #PurpleWhiteboard that was unregistered.
 	 *
 	 * Emitted after @whiteboard has been unregistered from @manager.
 	 *
 	 * Since: 3.0
 	 */
-	signals[SIG_UNREGISTERED] = g_signal_new_class_handler(
-		"unregistered",
+	signals[SIG_REMOVED] = g_signal_new_class_handler(
+		"removed",
 		G_OBJECT_CLASS_TYPE(klass),
 		G_SIGNAL_RUN_LAST,
 		NULL,
@@ -243,9 +243,8 @@
 }
 
 gboolean
-purple_whiteboard_manager_register(PurpleWhiteboardManager *manager,
-                                   PurpleWhiteboard *whiteboard,
-                                   GError **error)
+purple_whiteboard_manager_add(PurpleWhiteboardManager *manager,
+                              PurpleWhiteboard *whiteboard, GError **error)
 {
 	gboolean found = FALSE;
 
@@ -258,7 +257,7 @@
 
 	if(found) {
 		g_set_error(error, PURPLE_WHITEBOARD_MANAGER_DOMAIN, 0,
-		            _("whiteboard %s is already registered"),
+		            _("whiteboard %s has already been added"),
 		            purple_whiteboard_get_id(whiteboard));
 
 		return FALSE;
@@ -266,15 +265,14 @@
 
 	g_ptr_array_add(manager->whiteboards, g_object_ref(whiteboard));
 
-	g_signal_emit(manager, signals[SIG_REGISTERED], 0, whiteboard);
+	g_signal_emit(manager, signals[SIG_ADDED], 0, whiteboard);
 
 	return TRUE;
 }
 
 gboolean
-purple_whiteboard_manager_unregister(PurpleWhiteboardManager *manager,
-                                     PurpleWhiteboard *whiteboard,
-                                     GError **error)
+purple_whiteboard_manager_remove(PurpleWhiteboardManager *manager,
+                                 PurpleWhiteboard *whiteboard, GError **error)
 {
 	guint index = 0;
 	gboolean found = FALSE;
@@ -288,7 +286,7 @@
 
 	if(!found) {
 		g_set_error(error, PURPLE_WHITEBOARD_MANAGER_DOMAIN, 0,
-		            _("whiteboard %s is not registered"),
+		            _("whiteboard %s is not known"),
 		            purple_whiteboard_get_id(whiteboard));
 
 		return FALSE;
@@ -301,7 +299,7 @@
 
 	g_ptr_array_remove_index(manager->whiteboards, index);
 
-	g_signal_emit(manager, signals[SIG_UNREGISTERED], 0, whiteboard);
+	g_signal_emit(manager, signals[SIG_REMOVED], 0, whiteboard);
 
 	g_object_unref(whiteboard);
 
@@ -166,16 +166,16 @@
 	 * @manager: The #PurpleWhiteboardManager instance.
-	 * @whiteboard: The #PurpleWhiteboard that was registered.
+	 * @whiteboard: The #PurpleWhiteboard that was added.
 	 *
@@ -166,16 +166,16 @@
 	 *
-	 * Emitted after @whiteboard has been registered in @manager.
+	 * Emitted after @whiteboard has been added to @manager.
 	 *
 	 * Since: 3.0
@@ -187,16 +187,16 @@
 	 * @manager: The #PurpleWhiteboardManager instance.
-	 * @whiteboard: The #PurpleWhiteboard that was unregistered.
+	 * @whiteboard: The #PurpleWhiteboard that was removed.
 	 *
@@ -187,16 +187,16 @@
 	 *
-	 * Emitted after @whiteboard has been unregistered from @manager.
+	 * Emitted after @whiteboard has been removed from @manager.
 	 *
 	 * Since: 3.0